use bytemuck::{Pod, Zeroable};
use std::mem;
use wgpu;

#[repr(C)]
#[derive(Debug, Copy, Clone, Pod, Zeroable, Default)]
pub struct ImageLocation {
	// Image box, in texture coordinates
	pub xpos: f32,
	pub ypos: f32,
	pub width: f32,
	pub height: f32,
}

#[derive(Debug, Copy, Clone)]
pub struct ImageLocationArray {
	pub data: [ImageLocation; 108],
}

unsafe impl Pod for ImageLocationArray {}
unsafe impl Zeroable for ImageLocationArray {
	fn zeroed() -> Self {
		Self {
			data: [ImageLocation::zeroed(); 108],
		}
	}
}

impl Default for ImageLocationArray {
	fn default() -> Self {
		Self::zeroed()
	}
}

#[repr(C)]
#[derive(Debug, Copy, Clone, Default, Pod, Zeroable)]
pub struct AtlasContent {
	pub data: ImageLocationArray,
}

impl AtlasContent {
	pub const SIZE: u64 = mem::size_of::<Self>() as wgpu::BufferAddress;
}
